@@ -51,7 +51,7 @@ def transform_timeseries(
     oby_col = tss.order_by
     groups = get_ts_groups(data, tss)
     if not ts_analysis:
-        _, periods, freqs = get_delta(data, dtype_dict, groups, tss)
+        _, periods, freqs = get_delta(data, dtype_dict, groups, target, tss)
     else:
         periods = ts_analysis['periods']
         freqs = ts_analysis['sample_freqs']
@@ -60,13 +60,16 @@ def transform_timeseries(
     subsets = []
     for group in groups:
         if (tss.group_by and group != '__default') or not tss.group_by:
-            if periods[group] == 0:
-                raise Exception(
-                    f"Partition is not valid, faulty group {group}. Please make sure you group by a set of columns that ensures unique measurements for each grouping through time.")  # noqa
             idxs, subset = get_group_matches(data, group, tss.group_by)
             if subset.shape[0] > 0:
+                if periods.get(group, periods['__default']) == 0 and subset.shape[0] > 1:
+                    raise Exception(
+                        f"Partition is not valid, faulty group {group}. Please make sure you group by a set of columns that ensures unique measurements for each grouping through time.")  # noqa
+
                 index = pd.to_datetime(subset[oby_col], unit='s')
-                subset.index = pd.date_range(start=index.iloc[0], freq=freqs[group], periods=len(subset))
+                subset.index = pd.date_range(start=index.iloc[0],
+                                             freq=freqs.get(group, freqs['__default']),
+                                             periods=len(subset))
                 subset['__mdb_inferred_freq'] = subset.index.freq   # sets constant column because pd.concat forgets freq (see: https://github.com/pandas-dev/pandas/issues/3232)  # noqa
                 subsets.append(subset)
     original_df = pd.concat(subsets).sort_values(by='__mdb_original_index')
