@@ -42,6 +42,7 @@ def get_delta(
         df: pd.DataFrame,
         dtype_dict: dict,
         group_combinations: list,
+        target: str,
         tss
 ) -> Tuple[Dict, Dict, Dict]:
     """
@@ -49,6 +50,7 @@ def get_delta(
 
     :param df: Dataframe with time series data.
     :param group_combinations: all tuples with distinct values for `TimeseriesSettings.group_by` columns, defining all available time series.
+    :param target: name of target column
     :param tss: timeseries settings
 
     :return:
@@ -58,8 +60,8 @@ def get_delta(
     original_col = f'__mdb_original_{tss.order_by}'
     order_col = original_col if original_col in df.columns else tss.order_by
     deltas = {"__default": df[order_col].astype(float).rolling(window=2).apply(np.diff).value_counts().index[0]}
-    freq, period = detect_freq_period(deltas["__default"], tss)
-    periods = {"__default": period}
+    freq, period = detect_freq_period(deltas["__default"], tss, len(df))
+    periods = {"__default": [period]}
     freqs = {"__default": freq}
 
     if tss.group_by:
@@ -68,12 +70,15 @@ def get_delta(
                 _, subset = get_group_matches(df, group, tss.group_by)
                 if subset.shape[0] > 1:
                     deltas[group] = subset[order_col].rolling(window=2).apply(np.diff).value_counts().index[0]
-                    freq, period = detect_freq_period(deltas[group], tss)
-                    periods[group] = period
+                    freq, period = detect_freq_period(deltas[group], tss, len(subset))
                     freqs[group] = freq
+                    if period:
+                        periods[group] = [period]
+                    else:
+                        periods[group] = [max_pacf(df, group_combinations, target, tss)[group][0]]
                 else:
                     deltas[group] = 1.0
-                    periods[group] = 1
+                    periods[group] = [1]
                     freqs[group] = 'S'
 
     return deltas, periods, freqs
@@ -171,7 +176,7 @@ class Differencer:
         return series
 
 
-def detect_freq_period(deltas: pd.DataFrame, tss) -> tuple:
+def detect_freq_period(deltas: pd.DataFrame, tss, n_points) -> tuple:
     """
     Helper method that, based on the most popular interval for a time series, determines its seasonal peridiocity (sp).
     This bit of information can be crucial for good modelling with methods like ARIMA.
@@ -212,9 +217,12 @@ def detect_freq_period(deltas: pd.DataFrame, tss) -> tuple:
     }
     freq_to_period = {interval: period for (interval, period) in tss.interval_periods}
     for tag, period in (('yearly', 1), ('quarterly', 4), ('bimonthly', 6), ('monthly', 12),
-                        ('weekly', 4), ('daily', 1), ('hourly', 24), ('minute', 1), ('second', 1), ('constant', 0)):
+                        ('weekly', 52), ('daily', 7), ('hourly', 24), ('minute', 60), ('second', 60), ('constant', 0)):
         if tag not in freq_to_period.keys():
-            freq_to_period[tag] = period
+            if period <= n_points:
+                freq_to_period[tag] = period
+            else:
+                freq_to_period[tag] = None
 
     diffs = [(tag, abs(deltas - secs)) for tag, secs in secs_to_interval.items()]
     freq, min_diff = sorted(diffs, key=lambda x: x[1])[0]
